dhg.random
=============

Random Seed
---------------

.. autofunction:: dhg.random.seed

.. autofunction:: dhg.random.set_seed

Generating Features
-------------------

.. autofunction:: dhg.random.normal_features

Generating Graph
---------------------------------

.. autofunction:: dhg.random.graph_Gnp 

.. autofunction:: dhg.random.graph_Gnp_fast 

.. autofunction:: dhg.random.graph_Gnm 


Generating Directed Graph
---------------------------------

.. autofunction:: dhg.random.digraph_Gnp 

.. autofunction:: dhg.random.digraph_Gnp_fast 

.. autofunction:: dhg.random.digraph_Gnm 


Generating Bipartite Graph
---------------------------------

.. autofunction:: dhg.random.bigraph_Gnp 

.. autofunction:: dhg.random.bigraph_Gnm 


Generating Hypergraph
------------------------------------

.. autofunction:: dhg.random.uniform_hypergraph_Gnp 

.. autofunction:: dhg.random.uniform_hypergraph_Gnm 

.. autofunction:: dhg.random.hypergraph_Gnm 

